
# Slot: stage qualifier


stage during which gene or protein expression of takes place.

URI: [biolink:stage_qualifier](https://w3id.org/biolink/vocab/stage_qualifier)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [LifeStage](LifeStage.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children

 *  [gene to expression site association➞stage qualifier](gene_to_expression_site_association_stage_qualifier.md)

## Used by

 * [GeneExpressionMixin](GeneExpressionMixin.md)
 * [GeneToGeneCoexpressionAssociation](GeneToGeneCoexpressionAssociation.md)
 * [VariantToGeneExpressionAssociation](VariantToGeneExpressionAssociation.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example(value='UBERON:0000069', description='larval stage') |

